package com.srs.routine.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.dormitory.domain.DmsOutsideAccommodationApply;
import com.srs.routine.domain.RtEnlistmentReserve;

/**
 * 应征入伍保留学籍申请Service接口
 *
 * @author srs
 * @date 2025-10-31
 */
public interface IRtEnlistmentReserveService extends IService<RtEnlistmentReserve> {
    /**
     * 查询应征入伍保留学籍申请
     *
     * @param id 应征入伍保留学籍申请主键
     * @return 应征入伍保留学籍申请
     */
    public RtEnlistmentReserve selectRtEnlistmentReserveById(Long id);

    /**
     * 查询应征入伍保留学籍申请
     *
     * @param processInstanceId Flowable流程实例ID
     * @return 应征入伍保留学籍申请
     */
    public RtEnlistmentReserve selectRtEnlistmentReserveByProcessInstanceId(String processInstanceId);

    /**
     * 查询应征入伍保留学籍申请列表
     *
     * @param rtEnlistmentReserve 应征入伍保留学籍申请
     * @return 应征入伍保留学籍申请集合
     */
    List<RtEnlistmentReserve> selectRtEnlistmentReserveList(RtEnlistmentReserve rtEnlistmentReserve);

    /**
     * 新增应征入伍保留学籍申请
     *
     * @param rtEnlistmentReserve 应征入伍保留学籍申请
     * @return 结果
     */
    RtEnlistmentReserve insertRtEnlistmentReserve(RtEnlistmentReserve rtEnlistmentReserve);

    /**
     * 修改应征入伍保留学籍申请
     *
     * @param rtEnlistmentReserve 应征入伍保留学籍申请
     * @return 结果
     */
    int updateRtEnlistmentReserve(RtEnlistmentReserve rtEnlistmentReserve);

    /**
     * 批量删除应征入伍保留学籍申请
     *
     * @param ids 需要删除的应征入伍保留学籍申请主键集合
     * @return 结果
     */
    int deleteRtEnlistmentReserveByIds(Long[] ids);

    /**
     * 删除应征入伍保留学籍申请信息
     *
     * @param id 应征入伍保留学籍申请主键
     * @return 结果
     */
    int deleteRtEnlistmentReserveById(Long id);


    /**
     * 新增外宿申请
     *
     * @param dmsOutsideAccommodationApply 外宿申请
     * @return 结果
     */
    DmsOutsideAccommodationApply insertDmsOutsideAccommodationApply(DmsOutsideAccommodationApply dmsOutsideAccommodationApply);

    /**
     * 修改外宿申请
     *
     * @param dmsOutsideAccommodationApply 外宿申请
     * @return 结果
     */
    int updateDmsOutsideAccommodationApply(DmsOutsideAccommodationApply dmsOutsideAccommodationApply);
}
